@@ -12,7 +12,7 @@ def _read_parameter(param: Parameter, cfg: ConfigParser, section: str):
     annot = param.annotation
 
     if annot in (dict, Optional[dict]):
-        section_name = "{}.{}".format(section, param.name)
+        section_name = f"{section}.{param.name}"
         if section_name in cfg:
             return dict(cfg[section_name])
         return param.default
@@ -44,7 +44,7 @@ def _config_for_signature(cfg: ConfigParser, section: str, sig: Signature) -> di
     used_keys: Set[str] = set()
     for param in sig.parameters.values():
         if param.kind == Parameter.VAR_KEYWORD:
-            for (k, val) in cfg[section].items():
+            for k, val in cfg[section].items():
                 if k not in used_keys:
                     kwargs[k] = _parse_arg(val)
         elif param.kind != Parameter.VAR_POSITIONAL:
